@@ -61,4 +61,4 @@ class YoloHub:
 
 if __name__ == "__main__":
     model = YoloHub(config_path="torchyolo/default_config.yaml")
-    result = model.predict(tracker=True)
+    result = model.predict(tracker=False)
